@@ -1,3 +1,5 @@
+import six
+
 from hamcrest.core.base_matcher import Matcher
 from hamcrest.core.core.isequal import equal_to
 
@@ -5,6 +7,7 @@ __author__ = "Jon Reid"
 __copyright__ = "Copyright 2011 hamcrest.org"
 __license__ = "BSD, see License.txt"
 
+import types
 
 def wrap_matcher(x):
     """Wraps argument in a matcher, if necessary.
@@ -18,9 +21,11 @@ def wrap_matcher(x):
     else:
         return equal_to(x)
 
-
 def is_matchable_type(expected_type):
     if isinstance(expected_type, type):
         return True
 
+    if isinstance(expected_type, six.class_types):
+        return True
+
     return False
