@@ -1,7 +1,7 @@
-import warnings
-
 from hamcrest.core.selfdescribing import SelfDescribing
 
+import warnings
+
 __author__ = "Jon Reid"
 __copyright__ = "Copyright 2011 hamcrest.org"
 __license__ = "BSD, see License.txt"
@@ -18,7 +18,8 @@ class SelfDescribingValue(SelfDescribing):
     """
 
     def __init__(self, value):
-        warnings.warn("SelfDescribingValue no longer needed", DeprecationWarning)
+        warnings.warn('SelfDescribingValue no longer needed',
+                      DeprecationWarning)
         self.value = value
 
     def describe_to(self, description):
